'''
Package definition for 'posce'.
'''

VERSION_DATE   = '2020-03-18'
VERSION_NUMBER = '0.1.1'
VERSION_STRING = f'Posce version {VERSION_NUMBER} ({VERSION_DATE}).'

from posce import comms
from posce import items
from posce import tools
